ClientMetrics class

Client metrics for monitoring

Constructors

ClientMetrics()

Properties

averageResponseTime → Duration
no setter
errorCounts ↔ Map<String, int>
getter/setter pair
flagEvaluations ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
responseTimes ↔ List<Duration>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackingEvents ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited