Domain class

Constructors

Domain(String clientId, String providerName, {required DomainConfiguration config, Domain? parent})

Properties

children → List<Domain>
final
clientId → String
final
config → DomainConfiguration
final
effectiveSettings → Map<String, dynamic>
no setter
hashCode → int
The hash code for this object.
no setterinherited
parent → Domain?
final
providerName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isChildOf(Domain other) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited