DomainManager class

Constructors

DomainManager()

Properties

domainUpdates → Stream<Domain>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bindClientToProvider(String clientId, String providerName, {DomainConfiguration? config, String? parentDomainId}) → void
dispose() → void
getChildDomains(String domainId) → List<Domain>
getDomain(String clientId) → Domain?
getDomainSettings(String clientId) → Map<String, dynamic>
getProviderForClient(String clientId) → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateDomainSettings(String clientId, Map<String, dynamic> settings) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited