TargetingRule class

Represents a targeting rule for feature flag evaluation

Constructors

TargetingRule(String attribute, TargetingOperator operator, dynamic value, {Map<String, dynamic>? metadata, List<TargetingRule> subRules = const []})
const

Properties

attribute → String
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, dynamic>?
final
operator → TargetingOperator
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subRules → List<TargetingRule>
final
value → dynamic
final

Methods

evaluate(Map<String, dynamic> context) → bool
Evaluate the rule against a context
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited