EventBus class

Event bus for managing subscriptions and dispatching events

Constructors

EventBus({bool sync = false, int maxQueueSize = 1000})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
filterEvents(EventFilter filter) → Stream<OpenFeatureEvent>
getEventHistory() → List<OpenFeatureEvent>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publish(OpenFeatureEvent event) → void
subscribe(void handler(OpenFeatureEvent), {EventFilter? filter, bool autoAck = true}) → String
toString() → String
A string representation of this object.
inherited
unsubscribe(String subscriptionId) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited