OpenFeatureEvent class

Base event class

Constructors

OpenFeatureEvent({required String id, required OpenFeatureEventType type, required Map<String, dynamic> data, EventPriority priority = EventPriority.normal})

Properties

data → Map<String, dynamic>
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
priority → EventPriority
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
final
type → OpenFeatureEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited