TransactionContextPropagator class abstract interface

A request-local carrier. Implementations must isolate overlapping requests.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getTransactionContext() → EvaluationContext?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setTransactionContext<T>(EvaluationContext context, FutureOr<T> operation()) → Future<T>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited