ExtensionConfig class

Extension configuration

Constructors

ExtensionConfig({required String id, required String version, bool enabled = true, Map<String, dynamic> settings = const {}, List<String> dependencies = const [], Duration? timeout})
const

Properties

dependencies → List<String>
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → Map<String, dynamic>
final
timeout → Duration?
final
version → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited