ExtensionEvent class

Extension event

Constructors

ExtensionEvent({required String extensionId, required ExtensionState state, String? message, Object? error})

Properties

error → Object?
final
extensionId → String
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → ExtensionState
final
timestamp → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited