ExtensionMetadata class

Extension metadata

Constructors

ExtensionMetadata({required String id, required String version, required String author, required String description, List<String> tags = const [], Map<String, String> links = const {}})
const

Properties

author → String
final
description → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<String>
final
version → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited