ProviderConfig class

Provider configuration

Constructors

ProviderConfig({Duration connectionTimeout = const Duration(seconds: 30), Duration operationTimeout = const Duration(seconds: 5), int maxRetries = 3, Duration retryDelay = const Duration(seconds: 1), bool enableCache = true, Duration cacheTTL = const Duration(minutes: 5), int maxCacheSize = 1000, Map<String, dynamic> customConfig = const {}})
const

Properties

cacheTTL → Duration
final
connectionTimeout → Duration
final
customConfig → Map<String, dynamic>
final
enableCache → bool
final
hashCode → int
The hash code for this object.
no setterinherited
maxCacheSize → int
final
maxRetries → int
final
operationTimeout → Duration
final
retryDelay → Duration
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited