ProviderException class

Provider exception

Implemented types

Constructors

ProviderException(String message, {ErrorCode code = ErrorCode.GENERAL, Map<String, dynamic>? details})
const

Properties

code → ErrorCode
final
details → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited