ProviderMetadata class

Provider metadata

Constructors

ProviderMetadata({required String name, String version = '1.0.0', Map<String, String> attributes = const {}})
const

Properties

attributes → Map<String, String>
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited