before method
Before flag evaluation.
Returned context updates are merged into the evaluation context before the provider is called and before later before hooks execute.
Implementation
@override
Future<Map<String, dynamic>?> before(HookContext context) async => null;