Hook class abstract

Interface for implementing hooks

Implementers

Constructors

Hook()

Properties

hashCode → int
The hash code for this object.
no setterinherited
metadata → HookMetadata
Hook metadata and configuration
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

after(HookContext context) → Future<void>
After successful evaluation
before(HookContext context) → Future<Map<String, dynamic>?>
Before flag evaluation.
error(HookContext context) → Future<void>
When an error occurs
finally_(HookContext context, EvaluationDetails? evaluationDetails, [HookHints? hints]) → Future<void>
Always executed at the end, now with evaluation details parameter
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited