HookContext class

Context passed to hooks during execution

Constructors

HookContext({required String flagKey, Map<String, dynamic>? evaluationContext, dynamic result, Exception? error, Map<String, dynamic> metadata = const {}, ClientMetadata? clientMetadata, ProviderMetadata? providerMetadata, dynamic defaultValue, FlagValueType? flagValueType, HookData? hookData})

Properties

clientMetadata ClientMetadata?
final
defaultValue → dynamic
final
error Exception?
final
evaluationContext Map<String, dynamic>?
final
flagKey String
final
flagValueType FlagValueType?
final
hashCode int
The hash code for this object.
no setterinherited
hookData HookData
final
metadata Map<String, dynamic>
final
providerMetadata ProviderMetadata?
final
result → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited