HookHints class

Optional hints for hook execution

Constructors

HookHints({Map<String, dynamic> hints = const {}})
Legacy constructor; options and typed hooks capture an immutable snapshot.
const
HookHints.immutable(Map<String, dynamic> hints)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hints → Map<String, dynamic>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
snapshot() → HookHints
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited