HookMetadata class

Metadata for hook identification and configuration

Constructors

HookMetadata({required String name, String version = '1.0.0', HookPriority priority = HookPriority.NORMAL, HookConfig config = const HookConfig()})
const

Properties

config → HookConfig
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
priority → HookPriority
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited