StructuredLogEntry class

Structured log entry

Constructors

StructuredLogEntry({required Level level, required String message, required DateTime timestamp, Map<String, dynamic> context = const {}, String? error, StackTrace? stackTrace})

Properties

context → Map<String, dynamic>
final
error → String?
final
hashCode → int
The hash code for this object.
no setterinherited
level → Level
final
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
final
timestamp → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited