MultiProviderStrategy class abstract

Strategy for selecting a result from multiple providers.

Implementers

Constructors

MultiProviderStrategy()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

evaluate<T>({required String flagKey, required T defaultValue, required List<FeatureProvider> providers, required Future<FlagEvaluationResult<T>> evaluator(FeatureProvider provider)}) Future<FlagEvaluationResult<T>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited