OpenFeatureEvaluationContext class

Compatibility adapter for the legacy positional-map API. New code can use EvaluationContext.immutable and OpenFeatureAPI.setEvaluationContext directly.

Constructors

OpenFeatureEvaluationContext(Map<String, dynamic> attributes, {String? targetingKey})

Properties

attributes → Map<String, dynamic>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetingKey → String?
no setter

Methods

merge(OpenFeatureEvaluationContext other) → OpenFeatureEvaluationContext
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEvaluationContext() → EvaluationContext
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited