OpenFeatureEvent class

Implementers

Constructors

OpenFeatureEvent(OpenFeatureEventType type, String message, {dynamic data, ProviderMetadata? providerMetadata, FeatureProvider? provider, String? domain, ErrorCode? errorCode, List<String>? flagsChanged, Map<String, Object> eventMetadata = const {}, DateTime? timestamp})

Properties

data → dynamic
final
domain → String?
final
errorCode → ErrorCode?
final
errorMessage → String?
no setter
eventMetadata → Map<String, Object>
final
flagsChanged → List<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
provider → FeatureProvider?
final
providerMetadata → ProviderMetadata?
final
providerName → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
final
type → OpenFeatureEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited