provider_lifecycle library

Classes

DomainScopedProvider
Marker for provider instances that can be bound to only one domain.
ProviderEventSource
Optional capability for providers that own their v0.9 lifecycle events.
ProviderLifecycleEvent
A lifecycle event emitted directly by a feature provider.

Enums

ProviderLifecycleEventType
Lifecycle event types emitted by v0.9-capable providers.