ProviderLifecycleEvent class

A lifecycle event emitted directly by a feature provider.

Inheritance

Constructors

ProviderLifecycleEvent(OpenFeatureEventType type, String message, {dynamic data, ErrorCode? errorCode, List<String>? flagsChanged, Map<String, Object> eventMetadata = const {}, DateTime? timestamp})

Properties

data → dynamic
finalinherited
domain → String?
finalinherited
errorCode → ErrorCode?
finalinherited
errorMessage → String?
no setterinherited
eventMetadata → Map<String, Object>
finalinherited
flagsChanged → List<String>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
finalinherited
provider → FeatureProvider?
finalinherited
providerMetadata → ProviderMetadata?
finalinherited
providerName → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
finalinherited
type → OpenFeatureEventType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited