TransactionContext class

Transaction context holder

Constructors

TransactionContext({required String transactionId, required Map<String, dynamic> attributes, TransactionContext? parent})

Properties

attributes → Map<String, dynamic>
final
createdAt → DateTime
final
effectiveAttributes → Map<String, dynamic>
no setter
hashCode → int
The hash code for this object.
no setterinherited
parent → TransactionContext?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactionId → String
final

Methods

cleanup() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scheduleCleanup(Duration timeout) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited