FeatureProvider class abstract

Feature provider interface

Implementers

Constructors

FeatureProvider()

Properties

config ProviderConfig
no setter
hashCode int
The hash code for this object.
no setterinherited
metadata ProviderMetadata
no setter
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state ProviderState
no setter

Methods

connect() Future<void>
getBooleanFlag(String flagKey, bool defaultValue, {Map<String, dynamic>? context}) Future<FlagEvaluationResult<bool>>
getDoubleFlag(String flagKey, double defaultValue, {Map<String, dynamic>? context}) Future<FlagEvaluationResult<double>>
getIntegerFlag(String flagKey, int defaultValue, {Map<String, dynamic>? context}) Future<FlagEvaluationResult<int>>
getObjectFlag(String flagKey, Map<String, dynamic> defaultValue, {Map<String, dynamic>? context}) Future<FlagEvaluationResult<Map<String, dynamic>>>
getStringFlag(String flagKey, String defaultValue, {Map<String, dynamic>? context}) Future<FlagEvaluationResult<String>>
initialize([Map<String, dynamic>? config]) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shutdown() Future<void>
toString() String
A string representation of this object.
inherited
track(String trackingEventName, {Map<String, dynamic>? evaluationContext, TrackingEventDetails? trackingDetails}) Future<void>
Tracking API (spec Section 6) - record a tracking event Providers that do not support tracking should silently no-op.

Operators

operator ==(Object other) bool
The equality operator.
inherited