FlagEvaluationDetails<T> class
Evaluation details containing full context about flag evaluation
Constructors
-
FlagEvaluationDetails({required String flagKey, required T value, ErrorCode? errorCode, String? errorMessage, String? reason, String? variant, Map<
String, dynamic> ? flagMetadata}) -
FlagEvaluationDetails.fromResult(FlagEvaluationResult<
T> result) -
factory
Properties
- errorCode → ErrorCode?
-
final
- errorMessage → String?
-
final
- flagKey → String
-
final
-
flagMetadata
→ Map<
String, dynamic> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- reason → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
- value → T
-
final
- variant → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited