Minimal provider contract: metadata and five typed resolvers (2.1-2.2). Initialization, shutdown, hooks and tracking are optional capabilities declared in provider_capabilities.dart.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- metadata → ProviderMetadata
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getBooleanFlag(
String flagKey, bool defaultValue, {Map< String, dynamic> ? context}) → Future<FlagEvaluationResult< bool> > -
getDoubleFlag(
String flagKey, double defaultValue, {Map< String, dynamic> ? context}) → Future<FlagEvaluationResult< double> > -
getIntegerFlag(
String flagKey, int defaultValue, {Map< String, dynamic> ? context}) → Future<FlagEvaluationResult< int> > -
getObjectFlag(
String flagKey, Map< String, dynamic> defaultValue, {Map<String, dynamic> ? context}) → Future<FlagEvaluationResult< Map< >String, dynamic> > -
getStringFlag(
String flagKey, String defaultValue, {Map< String, dynamic> ? context}) → Future<FlagEvaluationResult< String> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited