TrackingEventDetails class

Tracking event details for the Tracking API (spec Section 6)

Constructors

TrackingEventDetails({double? value, Map<String, dynamic> attributes = const {}})
const

Properties

attributes Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited