before abstract method
Before flag evaluation.
Returned context updates are merged into the evaluation context before the provider is called and before later before hooks execute.
Implementation
Future<Map<String, dynamic>?> before(HookContext context);