FirstMatchStrategy class
Default Multi-Provider strategy.
Providers are evaluated in order. FLAG_NOT_FOUND results are treated as a
miss and the next provider is consulted. The first successful result wins.
If every provider misses, a single FLAG_NOT_FOUND result is returned. If
no provider succeeds and at least one provider returns another error, the
first non-FLAG_NOT_FOUND error is returned.
- Inheritance
-
- Object
- MultiProviderStrategy
- FirstMatchStrategy
Constructors
- FirstMatchStrategy()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
evaluate<
T> ({required String flagKey, required T defaultValue, required List< FeatureProvider> providers, required Future<FlagEvaluationResult< evaluator(FeatureProvider provider)}) → Future<T> >FlagEvaluationResult< T> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited