setEvaluationContext method
Set global evaluation fields using the canonical context representation. Existing clients resolve the latest snapshot on their next evaluation.
Implementation
void setEvaluationContext(EvaluationContext context) {
setGlobalContext(OpenFeatureEvaluationContext._(context.snapshot()));
}