OpenFeatureEvaluationContext class
Constructors
-
OpenFeatureEvaluationContext(Map<
String, dynamic> attributes, {String? targetingKey})
Properties
-
attributes
→ Map<
String, dynamic> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetingKey → String?
-
final
Methods
-
merge(
OpenFeatureEvaluationContext other) → OpenFeatureEvaluationContext -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toEvaluationContext(
) → EvaluationContext -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited