Optional v0.9 initialization. Lifecycle support includes provider-owned events, which must be emitted before initialization terminates (2.8.2-4).
- Implemented types
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
providerEvents
→ Stream<
ProviderLifecycleEvent> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
initializeProvider(
EvaluationContext context, {String? domain}) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited