Optional experimental tracking transport. Cleanup/flush belongs to the provider's shutdown capability; the SDK does not impose a vendor transport.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
trackEvent(
String name, {Map< String, dynamic> ? evaluationContext, TrackingEventDetails? trackingDetails}) → Future<void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited