ProviderLifecycleEvent class
A lifecycle event emitted directly by a feature provider.
Constructors
- ProviderLifecycleEvent(ProviderLifecycleEventType type, String message, {dynamic data, ErrorCode? errorCode, DateTime? timestamp})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited